summaryrefslogtreecommitdiffstats
path: root/win/CS/HandBrakeWPF/Services/Interfaces
diff options
context:
space:
mode:
Diffstat (limited to 'win/CS/HandBrakeWPF/Services/Interfaces')
-rw-r--r--win/CS/HandBrakeWPF/Services/Interfaces/IErrorService.cs59
-rw-r--r--win/CS/HandBrakeWPF/Services/Interfaces/IUpdateVersionService.cs22
2 files changed, 69 insertions, 12 deletions
diff --git a/win/CS/HandBrakeWPF/Services/Interfaces/IUpdateVersionService.cs b/win/CS/HandBrakeWPF/Services/Interfaces/IUpdateVersionService.cs
new file mode 100644
index 000000000..3a84e68fc
--- /dev/null
+++ b/win/CS/HandBrakeWPF/Services/Interfaces/IUpdateVersionService.cs
@@ -0,0 +1,22 @@
+// --------------------------------------------------------------------------------------------------------------------
+// <copyright file="IUpdateVersionService.cs" company="HandBrake Project (http://handbrake.fr)">
+// This file is part of the HandBrake source code - It may be used under the terms of the GNU General Public License.
+// </copyright>
+// <summary>
+// Defines the IUpdateVersionService type.
+// </summary>
+// --------------------------------------------------------------------------------------------------------------------
+
+namespace HandBrakeWPF.Services.Interfaces
+{
+ /// <summary>
+ /// The IUpdateVersionService Interface
+ /// </summary>
+ public interface IUpdateVersionService
+ {
+ /// <summary>
+ /// Get's HandBrakes version data from the CLI.
+ /// </summary>
+ void SetCliVersionData();
+ }
+} \ No newline at end of file
diff --git a/win/CS/HandBrakeWPF/Services/Interfaces/IErrorService.cs b/win/CS/HandBrakeWPF/Services/Interfaces/IErrorService.cs
index cba3a79b3..cc9ef968c 100644
--- a/win/CS/HandBrakeWPF/Services/Interfaces/IErrorService.cs
+++ b/win/CS/HandBrakeWPF/Services/Interfaces/IErrorService.cs
@@ -7,28 +7,63 @@
// </summary>
// --------------------------------------------------------------------------------------------------------------------
-using System.Windows;
-
namespace HandBrakeWPF.Services.Interfaces
{
+ using System;
+ using System.Windows;
+
+ /// <summary>
+ /// The Interface to the Error Service.
+ /// </summary>
public interface IErrorService
{
/// <summary>
/// Show an Error Window with debug output.
/// </summary>
- /// <param name="message"></param>
- /// <param name="solution"></param>
- /// <param name="details"></param>
+ /// <param name="message">
+ /// The message.
+ /// </param>
+ /// <param name="solution">
+ /// The solution.
+ /// </param>
+ /// <param name="details">
+ /// The details.
+ /// </param>
void ShowError(string message, string solution, string details);
/// <summary>
- /// Show a Message Box
+ /// Show an Exception Error Window
+ /// </summary>
+ /// <param name="message">
+ /// The message.
+ /// </param>
+ /// <param name="solution">
+ /// The solution.
+ /// </param>
+ /// <param name="exception">
+ /// The exception.
+ /// </param>
+ void ShowError(string message, string solution, Exception exception);
+
+ /// <summary>
+ /// Show a Message Box.
+ /// It is good practice to use this, so that if we ever introduce unit testing, the message boxes won't cause issues.
/// </summary>
- /// <param name="message"></param>
- /// <param name="header"></param>
- /// <param name="image"></param>
- /// <param name="buttons"></param>
- /// <returns></returns>
+ /// <param name="message">
+ /// The message.
+ /// </param>
+ /// <param name="header">
+ /// The header.
+ /// </param>
+ /// <param name="buttons">
+ /// The buttons.
+ /// </param>
+ /// <param name="image">
+ /// The image.
+ /// </param>
+ /// <returns>
+ /// The MessageBoxResult Object
+ /// </returns>
MessageBoxResult ShowMessageBox(string message, string header, MessageBoxButton buttons, MessageBoxImage image);
}
} \ No newline at end of file
@@ -7,28 +7,63 @@
{
/// <summary>
- /// Show an Error Window with debug output.
+ /// Show an Exception Error Window
/// </summary>